<?php
// Version: 2.0 RC5; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt, $modSettings;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 RC5';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as opposed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;

	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */
	$settings['require_theme_strings'] = true;

	loadLanguage('ThemeStrings');

	$context['smf4mobile_version'] = '1.0.1';
	$settings['use_image_buttons'] = false;
	$modSettings['compactTopicPagesEnable'] = false;

	// Portal disabling mafia
	// SimplePortal
	$settings['disable_sp'] = true;

	// TinyPortal
	if (function_exists('tp_hidebars'))
		tp_hidebars();


	// PortaMx
	$_SESSION['pmx_paneloff'] = array('head', 'top', 'left', 'right', 'bottom', 'foot', 'front', 'pages' => 'Pages');
	$modSettings['pmx_paneloff'] = 'head,top,left,right,bottom,foot,front,pages';

	// We'll be using this array a lot later
	$context['footer_controls'] = array();

	// Disable the Ad. management mod
	$modSettings['ads_quickDisable'] = true;

	// Whether to use native menu or not(never)
	$context['use_native_menu'] = 'false';

	// JS Lib compression, reduces to about 2/3rd the size
	$script_path = $settings['actual_theme_dir'] . '/scripts/';
	$js_files = array('jquery.js', 'jquery.mobile.js', 'script.js');
	$filemtime = file_exists($script_path . 'compiled.js') ? filemtime($script_path . 'compiled.js') : 0;
	$recompile = false;
	foreach ($js_files as $j)
		if (filemtime($script_path . $j) > $filemtime)
			$recompile = true;
	
	if ($recompile)
	{
		require_once($settings['actual_theme_dir'] . '/libs/jsmin.php');
		
		@unlink($script_path . 'compiled.js');
		$js = '';
		foreach ($js_files as $j)
			$js .= "\n" . file_get_contents($script_path . $j);
		$js = JSMin::minify($js);
		
		file_put_contents($script_path . 'compiled.js', $js);
	}
}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Absolutely shameful plug
	if (isset($txt['set_parameters']) && $context['page_title'] == $txt['set_parameters'])
		$context['page_title'] = $context['page_title_html_safe'] = $txt['_set_parameters'];

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '>
<head>';
	// Here comes the JavaScript bits!
	echo '
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/compiled.js"></script>
	<script type="text/javascript"><!-- // --><![CDATA[
		var a = navigator.userAgent.toLowerCase();
		var is_ios = a.indexOf("iphone") != -1 || a.indexOf("ipod") != -1 || a.indexOf("ipad") != -1;
		if (is_ios)
			$.mobile.defaultTransition = "slide";
		else
			$.mobile.defaultTransition = "none";
		$.mobile.ajaxEnabled = false;
		$.mobile.hashListeningEnabled = false;
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		var fPmPopup = function ()
		{
			if (confirm("' . $txt['show_personal_messages'] . '"))
				window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");
		}
		addLoadEvent(fPmPopup);' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";

	// ]]></script>
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/jquery.mobile.css" />';

	echo '
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />', !empty($context['meta_keywords']) ? '
	<meta name="keywords" content="' . $context['meta_keywords'] . '" />' : '', '
	<title>', $context['page_title_html_safe'], '</title>';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// Present a canonical url for search engines to prevent duplicate content in their indices.
	if (!empty($context['canonical_url']))
		echo '
	<link rel="canonical" href="', $context['canonical_url'], '" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="', $scripturl, '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	echo '
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
	<div data-role="page" data-theme="b" id="jqm">
		<div data-role="header" data-theme="b" data-backbtn="false">
			<h1>', $context['page_title'], '</h1>
			<a href="', $scripturl, '" data-icon="home" data-direction="reverse" data-iconpos="notext" class="ui-btn-right jqm-home">', $txt['home'], '</a>', count($context['linktree']) > 1 ? '
			<a href="' . $context['linktree'][count($context['linktree']) - 2]['url'] . '" data-icon="arrow-u" data-direction="reverse" class="ui-btn-left" data-iconpos="notext">' . $txt['back'] . '</a>' : '', '
		</div>';

	template_menu();

	// The main content should go here.
	echo '
		<div data-role="content" class="outer-background">';
}

function template_menu()
{
	global $context;

	echo '
		<div data-role="navbar">
			<ul>';

	// This is a hardcoded list of buttons that can be shown
	// The reason they are hardcoded is so that we do not show menu items that are not in the reach of this theme
	$button_list = array('forum', 'search', 'login', 'register', 'logout', 'pm', 'media');
	foreach ($context['menu_buttons'] as $id => $button)
		if (in_array($id, $button_list))
			echo '
				<li><a href="', $button['href'], '"', $button['active_button'] ? ' class="ui-btn-active"' : '', '>', $button['title'], '</a></li>';
	echo '
			</ul>
		</div>';
}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
		</div>';

	// God darn page index!
	if (isset($context['page_index']) || isset($context['aeva_page_index']))
		echo '
			<div class="ui-bar ui-bar-c smalltext pageindex">
				<div class="pagenav">
					', str_replace(array('[', ']'), '', !empty($context['page_index']) ? $context['page_index'] : $context['aeva_page_index']), '
				</div>
			</div>
			<script type="text/javascript">
			</script>';

	echo '
		<div data-role="footer" data-theme="b"><div class="ui-bar">';
	echo '
			<div style="display: inline; float:left; width: 30%;">
				<select name="page_menu" data-icon="grid" data-iconpos="notext" data-select-menu="true">
					<option data-theme="a">', $txt['navigation'], '</option>';
	foreach ($context['footer_controls'] as $control_group)
	{
		echo '
					<optgroup label="', $control_group['label'], '">';
		foreach ($control_group['buttons'] as $control_button)
			echo '
						<option data-theme="c" data-icon="', $control_button['icon'], '" value="', $control_button['url'], '"', !empty($control_button['confirm']) ? ' class="confirm" title="' . $control_button['confirm'] . '"' : '', '>
							', $control_button['text'], '
						</option>';
		echo '
					</optgroup>';
	}
	echo '
					<optgroup label="', $txt['common_actions'], '">
						<option data-theme="c" data-icon="arrow-r" value="' . $scripturl . '?action=recent">' . $txt['recent_posts'] . '</option>
				', $context['user']['is_logged'] ? '
						<option data-theme="c" data-icon="arrow-r" value="' . $scripturl . '?action=unread">' . $txt['view_unread_category'] . '</option>
						<option data-theme="c" data-icon="arrow-r" value="' . $scripturl . '?action=unreadreplies">' . $txt['unread_replies'] . '</option>
						<option data-theme="c" data-icon="arrow-r" value="' . $scripturl . '?action=profile">' . $txt['profile'] . '</option>' : '', allowedTo('who_view') && !empty($modSettings['who_enabled']) ? '
						<option data-theme="c" data-icon="arrow-r" value="' . $scripturl . '?action=who">' . $txt['who_title'] . '</option>' : '', '
					</optgroup>
				</select>
			</div>';

	echo '
			<div style="float: right; width:65%; text-align: right;" class="smalltext">
				', $context['user']['is_logged'] ? sprintf($txt['logged_in_as'], $context['user']['name']) : $txt['not_logged_in'], '
			</div>
		</div></div>';

	echo '

	<div id="footer_copyright">
		', !empty($context['aeva_copyright']) ? aeva_copyright() . '<br />': '', '
		<a href="', $scripturl, '?thememode=full;redirect=', urlencode(str_replace('thememode=mobile', '', $_SERVER['REQUEST_URL'])), '" data-role="button" data-inline="true" data-icon="forward" rel="external">', $txt['go_full_site'], '</a><br />
		SMF4Mobile ', $context['smf4mobile_version'], ' &copy; <a href="http://smf-media.com">SMF-Media.com</a><br /><br />
		',theme_copyright(), '
	</div></div>';

	// A little widget for confirming anchors
	echo '
	<div data-role="dialog" id="confirm_dialog">
		<div data-role="header" data-position="inline">
			<h1>', $txt['confirm_sure'], '</h1>
		</div>
		<div data-role="content" data-theme="c">
			<p class="dialog_message"></p>
			<div class="ui-grid-a">
				<div class="ui-block-a"><a class="dialog_confirm" data-role="button" href="" data-theme="a">', $txt['confirm'], '</a></div>
				<div class="ui-block-b"><a class="dialog_deny" data-role="button" href="#" data-rel="back">', $txt['cancel'], '</a></div>
			</div>
		</div>
	</div>
	<script type="text/javascript">
	</script>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '
				<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] . '</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo ' <span style="font-style: 15em;">></span> ';
	}

	$shown_linktree = true;
}

// Generate a strip of buttons.
function template_button_strip($button_strip, $group = 'page', $label = '', $new_format = false)
{
	global $settings, $context, $txt, $scripturl;

	if (empty($new_format))
		return template_button_strip($button_strip, 'page', $txt['page_actions'], true);

	if (empty($label))
		$label = $txt['page_actions'];

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		if (!isset($value['test']) || (is_bool($value['test']) && !empty($value['test'])) || !empty($context[$value['test']]))
			$buttons[] = array(
				'url' => $value['url'], 'text' => $txt[$value['text']], 'icon' => !empty($value['icon']) ? $value['icon'] : '', 'custom' => isset($value['custom']) ? $value['custom'] : '', 'confirm' => !empty($value['confirm']) ? $value['confirm'] : '',
			);
	}

	if (empty($context['footer_controls'][$group]))
		$context['footer_controls'][$group] = array(
			'label' => $label,
			'buttons' => array(),
		);

	$context['footer_controls'][$group]['buttons'] = array_merge((array) $context['footer_controls'][$group]['buttons'], $buttons);
}

?>